@@ -368,9 +368,15 @@ midori_history_initialize (KatzeArray*  array,
     }
 
     if (sqlite3_exec (db,
-                  "CREATE TABLE IF NOT EXISTS "
-                  "history(uri text, title text, date integer, day integer)",
-                  NULL, NULL, errmsg) != SQLITE_OK)
+                      "CREATE TABLE IF NOT EXISTS "
+                      "history (uri text, title text, date integer, day integer);"
+                      "CREATE TABLE IF NOT EXISTS "
+                      "search (keywords text, uri text, day integer);"
+                      "CREATE TEMP VIEW history_view AS SELECT "
+                      "1 AS type, uri, title, day FROM history;"
+                      "CREATE TEMP VIEW search_view AS SELECT "
+                      "2 AS type, uri, keywords AS title, day FROM search;",
+                      NULL, NULL, errmsg) != SQLITE_OK)
         return NULL;
 
     sqlite3_prepare_v2 (db, "SELECT day FROM history LIMIT 1", -1, &stmt, NULL);
@@ -1255,7 +1261,10 @@ midori_load_session (gpointer data)
     session = midori_browser_get_proxy_array (browser);
     i = 0;
     while ((item = katze_array_get_nth_item (_session, i++)))
+    {
+        g_object_set_data (G_OBJECT (item), "midori-view-append", (void*)1);
         midori_browser_add_item (browser, item);
+    }
     current = katze_item_get_meta_integer (KATZE_ITEM (_session), "current");
     if (current < 0)
         current = 0;
